      SUBROUTINE SMXM(A,N,B,M,C,L)
**
**    C = A * B
**    A ET B MATRICES A(N,M)  B(M,L) ==> C(N,L)
**
*>A      PREMIERE MATRICE
*>N      PREMIERE DIMENSION DE A ET DE C
*>B      DEUXIEME MATRICE
*>M      DEUXIEME DIMENSION DE A ET PERMIERE DE B
*<C      MATRICE PRODUIT DE A ET DE B
*>L      DEUXIEME DIMENSION DE B ET DE C
*A R. SANCHEZ ( EARLY WINTER 1987 )
*V M.F. ROBEAU
*M AM BAUDRON - AVRIL 94
*: ERREUR DANS L'APPEL A L'UTILITAIRE SGEMM
*: APPEL A L'UTILITAIRE SGEMM DE LA LIBRAIRIE BLAS SUR HP
*M AM BAUDRON - NOVEMBRE 1991
*: ERREUR ( SOMME SUR LES TERMES PAS FAITE )
*: APPEL A L'UTILITAIRE SGEMM DE LA LIBRAIRIE BLAS SUR RISC
*M AM BAUDRON - MAI 1993
*: CHANGEMENT DES %IF LOCAL SUN MIPS SUITE A INTRODUCTION VERSION IBM
      DIMENSION A(N,M),B(M,L),C(N,L)
      DO 20 I=1,N
      DO 20 J=1,L
         R=0.
         DO 10 K=1,M
            R=R+A(I,K)*B(K,J)
   10    CONTINUE
         C(I,J)=R
   20 CONTINUE
      RETURN
      END
